@@ -33,7 +33,7 @@
  * Tested with BusPirate PTH, firmware version 2.1 programming ATmega328P
  */
 
-/* $Id: buspirate.c 906 2010-01-12 09:52:40Z mludvig $ */
+/* $Id: buspirate.c 948 2010-10-22 14:29:56Z springob $ */
 
 #include "ac_cfg.h"
 
@@ -256,8 +256,9 @@ static int buspirate_send(struct programmer_t *pgm, char *str)
 
 static int buspirate_is_prompt(char *str)
 {
-	/* Prompt ends with '>' all other input probably ends with '\n' */
-	return (str[strlen(str) - 1] == '>');
+	/* Prompt ends with '>' or '> '
+	 * all other input probably ends with '\n' */
+	return (str[strlen(str) - 1] == '>' || str[strlen(str) - 2] == '>');
 }
 
 static int buspirate_expect(struct programmer_t *pgm, char *send,
@@ -373,7 +374,9 @@ static int buspirate_open(struct programmer_t *pgm, char * port)
 		pgm->baudrate = 115200;
 
 	strcpy(pgm->port, port);
-	serial_open(port, pgm->baudrate, &pgm->fd);
+	if (serial_open(port, pgm->baudrate, &pgm->fd)==-1) {
+	  return -1;
+	}
 
 	/* drain any extraneous input */
 	serial_drain(&pgm->fd, 0);
@@ -418,7 +421,7 @@ static void buspirate_reset_from_binmode(struct programmer_t *pgm)
 	}
 
 	if (verbose)
-		printf("BusPirate is back in the text mode\n");
+		fprintf(stderr, "BusPirate is back in the text mode\n");
 }
 
 static int buspirate_start_spi_mode_bin(struct programmer_t *pgm)
@@ -437,7 +440,8 @@ static int buspirate_start_spi_mode_bin(struct programmer_t *pgm)
 		return -1;
 	}
 	if (verbose)
-		printf("BusPirate binmode version: %d\n", PDATA(pgm)->binmode_version);
+		fprintf(stderr, "BusPirate binmode version: %d\n",
+			PDATA(pgm)->binmode_version);
 
 	pgm->flag |= BP_FLAG_IN_BINMODE;
 
@@ -452,7 +456,8 @@ static int buspirate_start_spi_mode_bin(struct programmer_t *pgm)
 		return -1;
 	}
 	if (verbose)
-		printf("BusPirate SPI version: %d\n", PDATA(pgm)->bin_spi_version);
+		fprintf(stderr, "BusPirate SPI version: %d\n",
+			PDATA(pgm)->bin_spi_version);
 
 	/* 0b0100wxyz - Configure peripherals w=power, x=pull-ups/aux2, y=AUX, z=CS
 	 * we want power (0x48) and all reset pins high. */
@@ -517,7 +522,7 @@ static int buspirate_start_spi_mode_ascii(struct programmer_t *pgm)
 		}
 		if (buspirate_is_prompt(rcvd)) {
 			if (strncmp(rcvd, "SPI>", 4) == 0) {
-				printf("BusPirate is now configured for SPI\n");
+				fprintf(stderr, "BusPirate is now configured for SPI\n");
 				break;
 			}
 			/* Not yet 'SPI>' prompt */
@@ -534,11 +539,12 @@ static int buspirate_start_spi_mode_ascii(struct programmer_t *pgm)
 static void buspirate_enable(struct programmer_t *pgm)
 {
 	unsigned char *reset_str = "#\n";
+	unsigned char *accept_str = "y\n";
 	char *rcvd;
 	int fw_v1 = 0, fw_v2 = 0;
 	int rc, print_banner = 0;
 
-	printf("Detecting BusPirate...\n");
+	fprintf(stderr, "Detecting BusPirate...\n");
 
 	/* Call buspirate_send_bin() instead of buspirate_send() 
 	 * because we don't know if BP is in text or bin mode */
@@ -557,6 +563,9 @@ static void buspirate_enable(struct programmer_t *pgm)
 			buspirate_enable(pgm);
 			return;
 		}
+		if (strncmp(rcvd, "Are you sure?", 13) == 0) {
+			buspirate_send_bin(pgm, accept_str, strlen(accept_str));
+		}
 		if (strncmp(rcvd, "RESET", 5) == 0) {
 			print_banner = 1;
 			continue;
@@ -568,7 +577,7 @@ static void buspirate_enable(struct programmer_t *pgm)
 		sscanf(rcvd, "Bus Pirate %9s", PDATA(pgm)->hw_version);
 		sscanf(rcvd, "Firmware v%d.%d", &fw_v1, &fw_v2);
 		if (print_banner)
-			printf("**  %s", rcvd);
+			fprintf(stderr, "**  %s", rcvd);
 	}
 
 	PDATA(pgm)->fw_version = 100 * fw_v1 + fw_v2;
@@ -581,12 +590,12 @@ static void buspirate_enable(struct programmer_t *pgm)
 		exit(1);
 
 	if (PDATA(pgm)->fw_version >= FW_BINMODE_VER && !(pgm->flag & BP_FLAG_XPARM_FORCE_ASCII)) {
-		printf("BusPirate: using BINARY mode\n");
+		fprintf(stderr, "BusPirate: using BINARY mode\n");
 		if (buspirate_start_spi_mode_bin(pgm) < 0)
 			fprintf(stderr, "%s: Failed to start binary SPI mode\n", progname);
 	}
 	if (!pgm->flag & BP_FLAG_IN_BINMODE) {
-		printf("BusPirate: using ASCII mode\n");
+		fprintf(stderr, "BusPirate: using ASCII mode\n");
 		if (buspirate_start_spi_mode_ascii(pgm) < 0) {
 			fprintf(stderr, "%s: Failed to start ascii SPI mode\n", progname);
 			exit(1);
