@@ -19,7 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: ppiwin.c 804 2009-02-23 22:04:57Z joerg_wunsch $ */
+/* $Id: ppiwin.c 936 2010-01-22 16:40:17Z joerg_wunsch $ */
 
 /*
 This is the parallel port interface for Windows built using Cygwin.
@@ -374,6 +374,7 @@ int gettimeofday(struct timeval *tv, struct timezone *unused){
 
 #endif
 
+#if !defined(HAVE_USLEEP)
 int usleep(unsigned int us)
 {
 	int has_highperf;
@@ -384,7 +385,7 @@ int usleep(unsigned int us)
 	// verify - increasing the delay helps sometimes but not
 	// realiably. There must be some other problem. Maybe just
 	// with my test-hardware maybe in the code-base.
-	//// us=(unsigned long) (us*1.5);	
+	//// us=(unsigned long) (us*1.5);
 
 	has_highperf=QueryPerformanceFrequency(&freq);
 
@@ -393,7 +394,7 @@ int usleep(unsigned int us)
 	if (has_highperf) {
 		QueryPerformanceCounter(&start);
 		loopend.QuadPart=start.QuadPart+freq.QuadPart*us/(1000*1000);
-		do { 
+		do {
 			QueryPerformanceCounter(&stop);
 		} while (stop.QuadPart<=loopend.QuadPart);
 	}
@@ -405,11 +406,12 @@ int usleep(unsigned int us)
 
 		DEBUG_QueryPerformanceCounter(&stop);
 	}
-	
+
     DEBUG_DisplayTimingInfo(start, stop, freq, us, has_highperf);
 
     return 0;
 }
+#endif  /* !HAVE_USLEEP */
 
 #endif
 
