@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: stk500.h 722 2007-01-24 22:43:46Z joerg_wunsch $ */
+/* $Id: stk500.h 845 2009-10-10 01:41:40Z mludvig $ */
 
 #ifndef stk500_h
 #define stk500_h
@@ -28,6 +28,10 @@ extern "C" {
 
 void stk500_initpgm (PROGRAMMER * pgm);
 
+/* used by arduino.c to avoid duplicate code */
+int stk500_getsync(PROGRAMMER * pgm);
+int stk500_drain(PROGRAMMER * pgm, int display);
+
 #ifdef __cplusplus
 }
 #endif
